We like to use XSPEC but it has to stay in a cage so it is not too dangerous.

Image of a docker container with XSPEC and poetry configured is available at [dockerhub](https://hub.docker.com/repository/docker/renecoty/heasoft/general).

``` code
docker pull renecoty/heasoft:poetry
```
